@@ -1,5 +1,6 @@
 AUTH_API = "https://he-accounts.force.com/SmartHome"
 API_URL = "https://api-iot.he.services"
+API_KEY = "GRCqFhC6Gk@ikWXm1RmnSmX1cm,MxY-configuration"
 APP = "hon"
 # All seen id's (different accounts, different devices) are the same, so I guess this hash is static
 CLIENT_ID = "3MVG9QDx8IX8nP5T2Ha8ofvlmjLZl5L_gvfbT9.HJvpHGKoAS_dcMN8LYpTSYeVFCraUnV.2Ag1Ki7m4znVO6"
@@ -7,4 +8,4 @@ APP_VERSION = "1.53.7"
 OS_VERSION = 31
 OS = "android"
 DEVICE_MODEL = "exynos9820"
-LANGUAGE = "en"
+USER_AGENT = "Chrome/110.0.5481.153"
